#
# spec file for package python-pycdlib
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pycdlib
Version:        1.14.0
Release:        1.9
Summary:        Pure python ISO manipulation library
License:        LGPL-2.0-only
Group:          Development/Languages/Python
URL:            https://github.com/clalancette/pycdlib
Source:         https://files.pythonhosted.org/packages/source/p/pycdlib/pycdlib-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  mkisofs
BuildRequires:  python-rpm-macros
BuildRequires:  timezone
Requires:       mkisofs
Requires:       python3-pycdlib-common
BuildArch:      noarch
%python_subpackages

%description
PyCdlib is a pure python library to parse, write (master), and create ISO9660
files, suitable for writing to a CD or USB.

The original ISO9660 (including ISO9660-1999) specification is supported, as
well the El Torito, Joliet, Rock Ridge, and UDF extensions.

Please see https://clalancette.github.io/pycdlib/ for much more documentation

%package -n python3-pycdlib-common
Summary:        Pure python ISO manipulation library - common files
Group:          Development/Languages/Python

%description -n python3-pycdlib-common
PyCdlib is a pure python library to parse, write (master), and create ISO9660
files, suitable for writing to a CD or USB.

The original ISO9660 (including ISO9660-1999) specification is supported, as
well the El Torito, Joliet, Rock Ridge, and UDF extensions.

This package includes the common files.

%prep
%setup -q -n pycdlib-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/pycdlib-explorer
%python_clone -a %{buildroot}%{_bindir}/pycdlib-extract-files
%python_clone -a %{buildroot}%{_bindir}/pycdlib-genisoimage

%check
export LC_ALL=ja_JP.UTF-8
export TZ=Asia/Tokyo
%pytest -k unit

%post
%{python_install_alternative pycdlib-explorer pycdlib-extract-files pycdlib-genisoimage}

%postun
%{python_uninstall_alternative pycdlib-explorer pycdlib-extract-files pycdlib-genisoimage}

%files %{python_files}
%doc README.md
%license COPYING
%python_alternative %{_bindir}/pycdlib-explorer
%python_alternative %{_bindir}/pycdlib-extract-files
%python_alternative %{_bindir}/pycdlib-genisoimage
%{python_sitelib}/*

%files -n python3-pycdlib-common
%{_mandir}/man1/pycdlib-explorer.1%{?ext_man}
%{_mandir}/man1/pycdlib-extract-files.1%{?ext_man}
%{_mandir}/man1/pycdlib-genisoimage.1%{?ext_man}

%changelog
* Thu Jan 19 2023 Dirk Müller <dmueller@suse.com>
- update to 1.14.0:
  * Fix Python 2 compatibility
  * Fix iteration over deep directories
  * Relax some error checking to allow non-standards-compliant ISOs to be read
  * Fix year rollover in the Australia timezone
  * Fix the use of inspect for modern Python 3
  * Add in pycdlib-explorer functionality for modify-in-place
  * Add full support for Windows raw block devices
  * Fix UDF entries for large files
  * Allow some UDF errors to print a warning instead of throwing
  * Search for UDF anchors in additional locations
  * Fix UDF partition map parsing
  * Several fixes to work with raw Windows devices
  * Fix ISOs with missing Apple partition map entries
  * Relax restrictions on dates hundredthsofseconds
  * Fix MBR boot code sector size
  * More UDF cleanups
* Sun Jul 18 2021 Dirk Müller <dmueller@suse.com>
- update to 1.11.0:
  * Add many more unit tests to get test coverage > 95%%
  * Preserve boot record contents when moving it
  * Make sure to allocate an extent for the boot_catalog in all cases
  * Fix deep directory depths with ISO level 4
  * Rewrite XA handling
  * Improve performance of filename checking
  * Add support for the AL record
  * Much improved IsoHybrid support for EFI/GTP
  * Fix large, multi-extent files
  * Fix support for very large ISOs
  * Remove the unused and unloved pycdlib-compare tool
  * Fix ISO9660 date hundredths of second
  * Much improved support for UDF
  * Switch to read-only open by default for the open() call
  * Fixes to work on big-endian machines
  * APIs added:
  * file_mode
  * APIs removed:
    None
  * APIs deprecated:
    None
  * Addition of "facades" for using PyCdlib in simpler ways
  * Make iso_path optional for UDF when using add_symlink
  * Make iso_path optional when using rm_file()
  * Make iso_path optional when using add_fp()/add_file()
  * Create symlinks appropriately in pycdlib-extract-files
  * Fix copy_data on macOS
  * Support more of the UDF standard
  * Cleanup documentation
  * Allow UEFI El Torito identifier
  * Add an 'auto' mode for pycdlib-extract-files
  * Add an '-extract-to' option for pycdlib-extract-files
  * APIs added:
  * get_iso9660_facade
  * get_joliet_facade
  * get_rock_ridge_facade
  * get_udf_facade
  * has_rockridge
  * has_joliet
  * has_udf
  * APIs removed:
    None
  * APIs deprecated:
    None
* Fri Jul 12 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.7.0
